Modules
- atomic
- Atomic types
Structs
- Arc
- A thread-safe reference-counting pointer. ‘Arc’ stands for ‘Atomically Reference Counted’.
- Weak
Weakis a version ofArcthat holds a non-owning reference to the managed allocation.- Exclusive
Experimental Exclusiveprovides mutable access, also referred to as exclusive access to the underlying value. However, it only permits immutable, or shared access to the underlying value when that value isSync.- Unique
Arc Experimental - A uniquely owned
Arc.